/* -*- Mode: js; indent-tabs-mode: nil; js-basic-offset: 4; tab-width: 4; -*- */
/*
 * This file is part of Transmission Daemon NG.
 * https://gitlab.gnome.org/glerro/gnome-shell-extension-transmission-daemon-ng
 *
 * prefs.js
 *
 * Copyright (c) 2023 Gianni Lerro {glerro} ~ <glerro@pm.me>
 *
 * Transmission Daemon NG is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Transmission Daemon NG is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License along
 * with Transmission Daemon NG. If not, see <https://www.gnu.org/licenses/>.
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 * SPDX-FileCopyrightText: 2023 Gianni Lerro <glerro@pm.me>
 */

/* exported init fillPreferencesWindow */

'use strict';

const {Adw, GObject, Gio} = imports.gi;

const ExtensionUtils = imports.misc.extensionUtils;
const Me = ExtensionUtils.getCurrentExtension();

const TEMPLATE_ADW = 'prefs_adw1.ui';

const TransmissionDaemonNGPrefsWidget = GObject.registerClass({
    GTypeName: 'TransmissionDaemonNGPrefsWidget',
    Template: Me.dir.get_child(TEMPLATE_ADW).get_uri(),
    InternalChildren: ['indicatorShowInStatus', 'numberOfTorrentShowInStatus',
        'speedUpDownIconShowInStatus', 'speedUpDownShowInStatus', 'hostname',
        'httpPortNumber', 'sslStatus', 'url', 'username', 'password'],
}, class TransmissionDaemonNGPrefsWidget extends Adw.PreferencesPage {
    _init(params = {}) {
        super._init(params);

        this._settings = ExtensionUtils.getSettings();

        this._settings.bind('always-show', this._indicatorShowInStatus,
            'active', Gio.SettingsBindFlags.DEFAULT);

        this._settings.bind('stats-torrents', this._numberOfTorrentShowInStatus,
            'active', Gio.SettingsBindFlags.DEFAULT);

        this._settings.bind('stats-icons', this._speedUpDownIconShowInStatus,
            'active', Gio.SettingsBindFlags.DEFAULT);

        this._settings.bind('stats-numeric', this._speedUpDownShowInStatus,
            'active', Gio.SettingsBindFlags.DEFAULT);

        this._settings.bind('host', this._hostname,
            'text', Gio.SettingsBindFlags.DEFAULT);

        this._settings.bind('port', this._httpPortNumber,
            'value', Gio.SettingsBindFlags.DEFAULT);

        this._settings.bind('ssl', this._sslStatus,
            'active', Gio.SettingsBindFlags.DEFAULT);

        this._settings.bind('url', this._url,
            'text', Gio.SettingsBindFlags.DEFAULT);

        this._settings.bind('user', this._username,
            'text', Gio.SettingsBindFlags.DEFAULT);

        this._settings.bind('password', this._password,
            'text', Gio.SettingsBindFlags.DEFAULT);
    }
});

/**
 * This function is called once when the Preferencs Windows is loaded.
 *
 * @function init
 */
function init() {
    console.log(`Inizializing Preferencs Windows of ${Me.metadata.name} - V${Me.metadata.version}`);

    ExtensionUtils.initTranslations();
}

/**
 * This function fill prefs window {Adw.PreferencesWindow}.
 *
 * @function fillPreferencesWindow
 * @param {Adw.PreferencesWindow} window - the prefs window.
 * @returns {void}
 */
function fillPreferencesWindow(window) {
    let prefsWidgetAdw = new TransmissionDaemonNGPrefsWidget();
    window.add(prefsWidgetAdw);
    window.set_default_size(640, 770);
}

